package com.hw.dms.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.hw.dms.mapper.DmsInspectRouteDetailMapper;
import com.hw.dms.domain.DmsInspectRouteDetail;
import com.hw.dms.service.IDmsInspectRouteDetailService;

/**
 * 巡检线路明细Service业务层处理
 *
 * @author Open Platform
 * @date 2024-01-16
 */
@Service
public class DmsInspectRouteDetailServiceImpl implements IDmsInspectRouteDetailService
{
    @Autowired
    private DmsInspectRouteDetailMapper dmsInspectRouteDetailMapper;

    /**
     * 查询巡检线路明细
     *
     * @param routeDetailId 巡检线路明细主键
     * @return 巡检线路明细
     */
    @Override
    public DmsInspectRouteDetail selectDmsInspectRouteDetailByRouteDetailId(Long routeDetailId)
    {
        return dmsInspectRouteDetailMapper.selectDmsInspectRouteDetailByRouteDetailId(routeDetailId);
    }

    /**
     * 查询巡检线路明细列表
     *
     * @param dmsInspectRouteDetail 巡检线路明细
     * @return 巡检线路明细
     */
    @Override
    public List<DmsInspectRouteDetail> selectDmsInspectRouteDetailList(DmsInspectRouteDetail dmsInspectRouteDetail)
    {
        return dmsInspectRouteDetailMapper.selectDmsInspectRouteDetailList(dmsInspectRouteDetail);
    }

    /**
     * 新增巡检线路明细
     *
     * @param dmsInspectRouteDetail 巡检线路明细
     * @return 结果
     */
    @Override
    public int insertDmsInspectRouteDetail(DmsInspectRouteDetail dmsInspectRouteDetail)
    {
        return dmsInspectRouteDetailMapper.insertDmsInspectRouteDetail(dmsInspectRouteDetail);
    }

    /**
     * 修改巡检线路明细
     *
     * @param dmsInspectRouteDetail 巡检线路明细
     * @return 结果
     */
    @Override
    public int updateDmsInspectRouteDetail(DmsInspectRouteDetail dmsInspectRouteDetail)
    {
        return dmsInspectRouteDetailMapper.updateDmsInspectRouteDetail(dmsInspectRouteDetail);
    }

    /**
     * 批量删除巡检线路明细
     *
     * @param routeDetailIds 需要删除的巡检线路明细主键
     * @return 结果
     */
    @Override
    public int deleteDmsInspectRouteDetailByRouteDetailIds(Long[] routeDetailIds)
    {
        return dmsInspectRouteDetailMapper.deleteDmsInspectRouteDetailByRouteDetailIds(routeDetailIds);
    }

    /**
     * 删除巡检线路明细信息
     *
     * @param routeDetailId 巡检线路明细主键
     * @return 结果
     */
    @Override
    public int deleteDmsInspectRouteDetailByRouteDetailId(Long routeDetailId)
    {
        return dmsInspectRouteDetailMapper.deleteDmsInspectRouteDetailByRouteDetailId(routeDetailId);
    }

    @Override
    public List<DmsInspectRouteDetail> selectInspectRouteListByInspectRouteId(Long inspectRouteId) {
        return dmsInspectRouteDetailMapper.selectInspectRouteListByInspectRouteId(inspectRouteId);
    }
}
