package com.hw.dms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import org.apache.poi.ss.formula.functions.T;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.dms.domain.DmsInspectRouteDetail;
import com.hw.dms.service.IDmsInspectRouteDetailService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 巡检线路明细Controller
 *
 * @author Open Platform
 * @date 2024-01-16
 */
@RestController
@RequestMapping("/dmsInspectRouteDetail")
public class DmsInspectRouteDetailController extends BaseController
{
    @Autowired
    private IDmsInspectRouteDetailService dmsInspectRouteDetailService;

    /**
     * 查询巡检线路明细列表
     */
    @RequiresPermissions("dms:dmsInspectRouteDetail:list")
    @GetMapping("/list")
    public TableDataInfo list(DmsInspectRouteDetail dmsInspectRouteDetail)
    {
        startPage();
        List<DmsInspectRouteDetail> list = dmsInspectRouteDetailService.selectDmsInspectRouteDetailList(dmsInspectRouteDetail);
        return getDataTable(list);
    }

    /** 通过线路id查询线路明细列表*/
    @GetMapping("/selectInspectRouteListByInspectRouteId/{inspectRouteId}")
    public TableDataInfo selectInspectRouteListByInspectRouteId(@PathVariable("inspectRouteId") Long inspectRouteId){
        List<DmsInspectRouteDetail> dmsInspectRouteDetails = dmsInspectRouteDetailService.selectInspectRouteListByInspectRouteId(inspectRouteId);
        return getDataTable(dmsInspectRouteDetails);
    }
    /**
     * 导出巡检线路明细列表
     */
    @RequiresPermissions("dms:dmsInspectRouteDetail:export")
    @Log(title = "巡检线路明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsInspectRouteDetail dmsInspectRouteDetail)
    {
        List<DmsInspectRouteDetail> list = dmsInspectRouteDetailService.selectDmsInspectRouteDetailList(dmsInspectRouteDetail);
        ExcelUtil<DmsInspectRouteDetail> util = new ExcelUtil<DmsInspectRouteDetail>(DmsInspectRouteDetail.class);
        util.exportExcel(response, list, "巡检线路明细数据");
    }

    /**
     * 获取巡检线路明细详细信息
     */
    @RequiresPermissions("dms:dmsInspectRouteDetail:query")
    @GetMapping(value = "/{routeDetailId}")
    public AjaxResult getInfo(@PathVariable("routeDetailId") Long routeDetailId)
    {
        return success(dmsInspectRouteDetailService.selectDmsInspectRouteDetailByRouteDetailId(routeDetailId));
    }

    /**
     * 新增巡检线路明细
     */
    @RequiresPermissions("dms:dmsInspectRouteDetail:add")
    @Log(title = "巡检线路明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsInspectRouteDetail dmsInspectRouteDetail)
    {
        return toAjax(dmsInspectRouteDetailService.insertDmsInspectRouteDetail(dmsInspectRouteDetail));
    }

    /**
     * 修改巡检线路明细
     */
    @RequiresPermissions("dms:dmsInspectRouteDetail:edit")
    @Log(title = "巡检线路明细", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsInspectRouteDetail dmsInspectRouteDetail)
    {
        return toAjax(dmsInspectRouteDetailService.updateDmsInspectRouteDetail(dmsInspectRouteDetail));
    }

    /**
     * 删除巡检线路明细
     */
    @RequiresPermissions("dms:dmsInspectRouteDetail:remove")
    @Log(title = "巡检线路明细", businessType = BusinessType.DELETE)
	@DeleteMapping("/{routeDetailIds}")
    public AjaxResult remove(@PathVariable Long[] routeDetailIds)
    {
        return toAjax(dmsInspectRouteDetailService.deleteDmsInspectRouteDetailByRouteDetailIds(routeDetailIds));
    }
}
